Marine Sponges Data Base

# Info on Marine Sponges Data Base

    1. Title: Marine Sponges, O.HADROMERIDA (DEMOSPONGIAE.PORIFERA)

    2. Source Information:
       -- Creators: Iosune Uriz and Marta Domingo
    		Centre d'Estudis Aban\c{c}ats de Blanes (CSIC)
    		Cami de Santa Barbara. Blanes (Girona). Spain
       -- Donor: Javier B\'ejar and Ulises Cort\'es (bejar@lsi.upc.es)
             Dept. Llenguatges i Sistemes Inform\`atics;
             Universitat Politecnica de Catalunya. Barcelona; Spain
       -- Date: September, 1994

    3. Past Usage:
       1. Domingo, M.
          ``Aplicaci\'o de t\`ecniques de I.A. (LINNEO) a la classificaci\'o
            sistem\`atica: O.Hadromerida (Demospongiae.Porifera). Master
            Thesis. Departament d'ecologia. Universitat de Barcelona.

       2. Martin, M and Sanguesa, R. and Cor\'es
          ``Biasing induction with previous knowledge for knowledge acquisition
            in imprecise domains''.
          Les syst\`emes experts et leus applications.
          Onzi\'emes Journ\'ees Internationales. Avignon'91.
          Vol 1. pp. 359-370. Avignon, France. 1991.

       3. Martin, M. and Sanguesa, R. and Cort\'es U.
          `` Knowledge acquisition combining analytical and empirical
    	 techniques''.
          Proceedings of the Eighth International Workshop of Machine Learning.
          ML 91. pp 657-661. Evanston, Illinois, USA 1991.

       4. Bejar, J. and Cort\'es, U.
          ``LINNEO+: Herramienta para la adquisicion de conocimiento y generacion
            de reglas de clasificaci\'on en dominios poco estructurados''.
          Proceedings del III Congreso Iberoamericano de Inteligencia Artificial.
          IBERAMIA 92. pp 471-482. La Habana (Cuba).

    4. Relevant Information:

    	These are atlantic-mediterranean marine sponges taht belong to
    	O.Hadromerida (Demospongiae.Porifera).

    5. Number of instances: 76

    6. Number of Attributes: 45

         There are some missing values, all are unknown information.

    7. Attribute Information:

       27 attributes are non-numeric and nominal.
       15 attributes are boolean and take the values (NO SI).
        3 attributes are numeric and take natural numbers.

    Num.  Attribute.                               Range and possible values.
    ----  ----------                               --------------------------
     1    A.CAPAS_DEL_CORTEX                       (1_CAPA 2_CAPAS 3_CAPAS SIN_CORTEX)
     2    A.CAPA_INTERNA_DEL_CORTEX                (BANDAS_DE_ESPICULAS_CRUZADAS MICROSCLERAS PERPENDICULAR SIN_CAPA_INTERNA_DEL_CORTEX TANGENCIAL TANGENCIAL_Y_PERPENDICULAR)
     3    A.CORTEX                                 (NO SI)
     4    A.CORTEX_FIBROSO                         (NO SI SIN_CORTEX)
     5    A.CORTEX_SOLO_DE_ESPICULAS_TANGENCIALES  (NO SI SIN_CORTEX)
     6    A.CUERPOS_EXTRANOS_EN_EL_CORTEX          (NO SI SIN_CORTEX)
     7    A.GROSOR_DEL_CORTEX                      (0 4)
     8    A.HACES_DE_ESPICULAS_PRINCIPALES_EN_POMPON_EN_EL_CORTEX     (NO SI)
     9    A.TILOSTILOS_ADICIONALES_COANOSOMA       (ECTOSOMICOS_DISPERSOS ECTOSOMICOS_EN_RAMILLETES INTERMEDIARIOS INTERMEDIARIOS_Y_ECTOSOMICOS SIN_TILOSTILOS_ADICIONALES)
    10    B.NUMERO_DE_TIPOS_DE_MEGASCLERAS         (1_TIPO 2_TIPOS 3_TIPOS)
    11    C.TIPO_ESPICULA_PRINCIPAL_DIACTINA_TUBERCULADA              (NO SI)
    12    C.TIPO_ESPICULA_PRINCIPAL_ESTILO         (NO SI)
    13    C.TIPO_ESPICULA_PRINCIPAL_ESTILOS_2_TAMANOS                 (NO SI)
    14    C.TIPO_ESPICULA_PRINCIPAL_ESTILO_TILOSTILO                  (NO SI)
    15    C.TIPO_ESPICULA_PRINCIPAL_ESTRONGILOXA   (NO SI)
    16    C.TIPO_ESPICULA_PRINCIPAL_OXAS           (NO SI)
    17    C.TIPO_ESPICULA_PRINCIPAL_TILOSTILO      (NO SI)
    18    D.ESPICULA_PRINCIPAL_ESTILO              (FUSIFORME NORMAL POLITILOTA SIN_ESPICULA_PRINCIPAL_ESTILO)
    19    D.ESPICULA_PRINCIPAL_TILOSTILO           (FLEXUOSA FUSIFORME NORMAL POLITILOTA SIN_ESPICULA_PRINCIPAL_TILOSTILO_)
    20    D.FORMA_BASE_TILOSTILO_PRINCIPAL         (POMO SIN_TILOSTILOS SUBESFERICA_ALARGADA_OVOIDE TRILOBULADA)
    21    E.DISPOSICION_MEGASCLERAS_ECTOSOMICAS_EN_EL_ECTOSOMA        (EMPALIZADA RAMILLETES SIN_MEGASCLERAS_ECTOSOMICAS TANGENCIALES)
    22    E.FORMA_BASE_TILOSTILO_ECTOSOMICO        (SIN_TILOSTILO_ECTOSOMICO SUBESFERICA_ALARGADA_OVOIDE TRILOBULADA_CON_VESICULA_AXIAL)
    23    E.FORMA_MEGASCLERA_ECTOSOMICA            (CURVADA RECTA_FUSIFORME RECTA_NO_FUSIFORME SIN_MEGASCLERA_ECTOSOMICA)
    24    E.TIPO_MEGASCLERA_ECTOSOMICA             (ESTILO ESTILO_TILOSTILO OXAS_ESTRONGILOXAS SIN_MEGASCLERA_ECTOSOMICA TILOSTILO)
    25    F.TIPO_DE_EXOSTILO                       (ANATRIENAS CLADOTILOSTILOS ESFEROTILOS SIN_EXOSTILOS TILOSTILOS_ESPINOSOS_EN_LA_PUNTA TILOSTILO_LISO)
    26    G.FORMA_MEGASCLERA_INTERMEDIARIA         (FUSIFORME NORMAL POLITILOTA SIN_MEGASCLERA_INTERMEDIARIA)
    27    G.TIPO_MEGASCLERA_INTERMEDIARIA          (ESTILO ESTILO_TILOSTILO SIN_MEGASCLERA_INTERMEDIARIA TILOSTILO)
    28    H.LONGITUD_MEGASCLERAS                   (0 3)
    29    I.MICROSCLERAS                           (NO SI)
    30    I.TIPO_MICROSCLERA                       (ASTER MICROESTILOS_Y_MICROXAS MICROESTRONGILOS_CENTROTILOTES SIN_MICROSCLERAS TRICODRAGMA)
    31    J.ASTER                                  (NO SI)
    32    J.DIAMETRO_ESFERASTER                    (|10_12| |20_25| |27_44| |40_110| |5_6_Y_15_35| SIN_ESFERASTER)
    33    J.TIPO_DE_ASTER                          (ANFIASTER DIPLASTER ESFERASTER ESPIRASTER QUIASTER QUIASTER_Y_ESFERASTER SIN_ASTER)
    34    J.TIPO_DE_DIPLASTER                      (CON_ACTINAS_COMPLEJAS CON_ACTINAS_SIMPLES SIN_DIPLASTERES)
    35    J.TIPO_DE_ESFERASTER                     (OXIESFERASTER OXIESFERASTER_Y_TILOESFERASTER SIN_ESFERASTER)
    36    K.FORMA_FINAL                            (DE_CONO_INVERTIDO DE_REVESTIMIENTO GLOBULOSA HEMISFERICA INCRUSTANTE MASIVO_IRREGULAR MAZAS_PEDUNCULADAS_1/PEDUNCULO MAZAS_PEDUNCULADAS_VARIAS/PEDUNCULO RAMIFICADA)
    37    L.NUMERO_DE_PAPILAS                      (0 4)
    38    L.PAPILAS                                (NO SI)
    39    M.COLOR                                  (AMARILLO_PALIDO AZUL_O_ANARANJADO_INTENSOS OTROS)
    40    N.SUPERFICIE                             (ATERCIOPELADA CON_AREAS_POLIGONALES_ABULTADAS FRANJA_BASAL_DE_ESPICULAS_EN_FLECO HISPIDEZ_MAYOR_HACIA_LA_BASE LISA RUGOSA SOLO_PAPILAS_LISAS TOTALMENTE_HISPIDA)
    41    O.DISPOSICION_ESPICULAR_ESQUELETO        (AXIAL CONFUSA HYMEDESMOIDE PLUMOSA RADIAL RADIAL_EN_PERIFERIA REDUCIDO)
    42    P.ALOJA_CANGREJO_ERMITANO                (NO SI)
    43    P.PERFORANTE                             (NO SI)
    44    P.PSEUDORAICES                           (NO SI)
    45    P.SUSTRATO                               (AMBOS BLANDO DURO)

    Statistics
    ==========

    Num.	 Var.     Ocurrence distribution for nominal and boolean attributes
    ----	-----     ---------------------------=======-----=======-----------
     1	0.902	  (1_CAPA 0.20) (2_CAPAS 0.30) (3_CAPAS 0.07) (SIN_CORTEX 0.43)
     2 	0.679	  (BANDAS_DE_ESPICULAS_CRUZADAS 0.04) (MICROSCLERAS 0.03) (PERPENDICULAR 0.05) (TANGENCIAL 0.25) (TANGENCIAL_Y_PERPENDICULAR 0.03) (SIN_CAPA_INTERNA_DEL_CORTEX 0.61)
     3	0.983	  (NO 0.43) (SI 0.57)
     4	0.836	  (NO 0.50) (SI 0.07) (SIN_CORTEX 0.43)
     5	0.759	  (NO 0.55) (SI 0.01) (SIN_CORTEX 0.43)
     6	0.759	  (NO 0.55) (SI 0.01) (SIN_CORTEX 0.43)
     8	0.102	  (NO 0.97) (SI 0.03)
     9	0.774	  (ECTOSOMICOS_DISPERSOS 0.08) (ECTOSOMICOS_EN_RAMILLETES 0.11) (INTERMEDIARIOS 0.13) (INTERMEDIARIOS_Y_ECTOSOMICOS 0.11) (SIN_TILOSTILOS_ADICIONALES 0.58)
    10	0.964	  (1_TIPO 0.37) (2_TIPOS 0.21) (3_TIPOS 0.42)
    11	0.052	  (NO 0.99) (SI 0.01)
    12	0.457	  (NO 0.87) (SI 0.13)
    13	0.052	  (NO 0.99) (SI 0.01)
    14	0.418	  (NO 0.88) (SI 0.12)
    15	0.334	  (NO 0.91) (SI 0.09)
    16	0.334	  (NO 0.91) (SI 0.09)
    17	0.864	  (NO 0.32) (SI 0.68)
    18	0.571	  (FUSIFORME 0.11) (NORMAL 0.13) (POLITILOTA 0.03) (SIN_ESPICULA_PRINCIPAL_ESTILO 0.74)
    19	0.841	  (FUSIFORME 0.22) (NORMAL 0.47) (POLITILOTA 0.09) (SIN_ESPICULA_PRINCIPAL_TILOSTILO_ 0.21)
    20	0.634	  (POMO 0.01) (SUBESFERICA_ALARGADA_OVOIDE 0.68) (TRILOBULADA 0.08) (SIN_TILOSTILOS 0.22)
    21	0.756	  (EMPALIZADA 0.51) (RAMILLETES 0.04) (TANGENCIALES 0.04) (SIN_MEGASCLERAS_ECTOSOMICAS 0.41)
    22	0.821	  (SUBESFERICA_ALARGADA_OVOIDE 0.50) (TRILOBULADA_CON_VESICULA_AXIAL 0.05) (SIN_TILOSTILO_ECTOSOMICO 0.45)
    23 	0.911	  (CURVADA 0.33) (RECTA_FUSIFORME 0.13) (RECTA_NO_FUSIFORME 0.12) (SIN_MEGASCLERA_ECTOSOMICA 0.42)
    24	0.713	  (ESTILO 0.01) (ESTILO_TILOSTILO 0.04) (OXAS_ESTRONGILOXAS 0.03) (TILOSTILO 0.50) (SIN_MEGASCLERA_ECTOSOMICA 0.42)
    25	0.209	  (ANATRIENAS 0.01) (CLADOTILOSTILOS 0.01) (ESFEROTILOS 0.03) (TILOSTILOS_ESPINOSOS_EN_LA_PUNTA 0.01) (TILOSTILO_LISO 0.03) (SIN_EXOSTILOS 0.91)
    26	0.701	  (FUSIFORME 0.17) (NORMAL 0.17) (POLITILOTA 0.01) (SIN_MEGASCLERA_INTERMEDIARIA 0.64)
    27	0.664	  (ESTILO 0.04) (ESTILO_TILOSTILO 0.03) (TILOSTILO 0.29) (SIN_MEGASCLERA_INTERMEDIARIA 0.64)
    29	0.823	  (NO 0.71) (SI 0.29)
    30	0.567	  (ASTER 0.20) (MICROESTILOS_Y_MICROXAS 0.04) (MICROESTRONGILOS_CENTROTILOTES 0.03) (TRICODRAGMA 0.03) (SIN_MICROSCLERAS 0.71)
    31	0.665	  (NO 0.79) (SI 0.21)
    32	0.180	  (10_12 0.01) (20_25 0.01) (27_44 0.01) (40_110 0.03) (5_6_Y_15_35 0.01) (SIN_ESFERASTER 0.92)
    33	0.426	  (ANFIASTER 0.01) (DIPLASTER 0.03) (ESFERASTER 0.07) (ESPIRASTER 0.08) (QUIASTER 0.01) (QUIASTER_Y_ESFERASTER 0.01) (SIN_ASTER 0.79)
    34	0.077	  (CON_ACTINAS_COMPLEJAS 0.01) (CON_ACTINAS_SIMPLES 0.01) (SIN_DIPLASTERES 0.97)
    35	0.221	  (OXIESFERASTER 0.07) (OXIESFERASTER_Y_TILOESFERASTER 0.01) (SIN_ESFERASTER 0.92)
    36	0.922	  (DE_CONO_INVERTIDO 0.01) (DE_REVESTIMIENTO 0.24) (GLOBULOSA 0.13) (HEMISFERICA 0.08) (INCRUSTANTE 0.26) (MASIVO_IRREGULAR 0.12) (MAZAS_PEDUNCULADAS_1/PEDUNCULO 0.13) (MAZAS_PEDUNCULADAS_VARIAS/PEDUNCULO 0.01) (RAMIFICADA 0.01)
    38	0.994	  (NO 0.54) (SI 0.46)
    39	0.551	  (AMARILLO_PALIDO 0.22) (AZUL_O_ANARANJADO_INTENSOS 0.01) (OTROS 0.76)
    40	0.928	  (ATERCIOPELADA 0.18) (CON_AREAS_POLIGONALES_ABULTADAS 0.03) (FRANJA_BASAL_DE_ESPICULAS_EN_FLECO 0.03) (HISPIDEZ_MAYOR_HACIA_LA_BASE 0.07) (LISA 0.32) (RUGOSA 0.12) (SOLO_PAPILAS_LISAS 0.13) (TOTALMENTE_HISPIDA 0.13)
    41	0.861	  (AXIAL 0.07) (CONFUSA 0.16) (HYMEDESMOIDE 0.13) (PLUMOSA 0.04) (RADIAL 0.45) (RADIAL_EN_PERIFERIA 0.11) (REDUCIDO 0.05)
    42	0.102	  (NO 0.97) (SI 0.03)
    43	0.291	  (NO 0.92) (SI 0.08)
    44	0.199	  (NO 0.95) (SI 0.05)
    45	0.223	  (AMBOS 0.04) (BLANDO 0.04) (DURO 0.92)

    Num.   min      max       mean      st-dev  (for numeric attributes)
    ----   ---      ---       -----     ------
     7	0	 4	  1.578	    1.524
    28      0        3        2.236     0.886
    37      0        4        0.986     1.219

    8. Missing Attribute Values:

         N.  Attrib.   N. of Missings
         --  -------   --------------
         39  M.COLOR   22

    9. Class Distribution

       These are the classes induced by our conceptual clustering algorithm:

      -- Class 1:
        - Objects (6 sponges):

          TYLEXOCLADUS_JOUBINI TRACHYTELEIA_STEPHENSI TENTORIUM_SEMISUBERITES
          TENTORIUM_PAPILLATUS SUBERITES_CAMINATUS SPINULARIA_SPINULARIA AAPTOS_AAPTOS

      -- Class 2:
        - Objects (10 sponges):

          SPIRASTRELLA_MINAX SPIRASTRELLA_CUNCTATRIX LAXOSUBERITES_ECTYONIMUS
          DIPLASTRELLA_ORNATA DIPLASTRELLA_BISTELLATA CLIONA_SCHMIDTI
          CLIONA_LABYRINTHICA CLIONA_CELATA CLIONA_CARTERI ALECTONA_MILLARI

      -- Class 3:
        - Objects (1 sponges):

          CLIONA_VIRIDIS

      -- Class 4:
        - Objects (16 sponges):

          TERPIOS_FUGAX SUBERITES_GIBBOSICEPS SUBERITES_CARNOSUS_V.TYPICUS
          SUBERITES_CARNOSUS_V.RAMOSUS SUBERITES_CARNOSUS_V.INCRUSTANS RHIZAXINELLA_UNISETA
          RHIZAXINELLA_PYRIFERA RHIZAXINELLA_ELONGATA RHIZAXINELLA_BISETA
          PSEUDOSUBERITES_SULFUREUS PSEUDOSUBERITES_HYALINUS PROSUBERITES_RUGOSUS
          PROSUBERITES_LONGISPINA PROSUBERITES_EPIPHYTUM LAXOSUBERITES_RUGOSUS
          LAXOSUBERITES_FERRERHERNANDEZI

      -- Class 5:
        - Objects (2 sponges):

          STYLOCORDYLA_BOREALIS OXYCORDYLA_PELLITA

      -- Class 6:
        - Objects (16 sponges):

         SPHAEROTYLUS_CAPITATUS PROTELEIA_SOLLASI POLYMASTIA_UBERRIMA
         POLYMASTIA_TENAX POLYMASTIA_SPINULA POLYMASTIA_ROBUSTA
         POLYMASTIA_RADIOSA POLYMASTIA_POLYTYLOTA POLYMASTIA_MAMMILLARIS
         POLYMASTIA_LITTORALIS POLYMASTIA_INVAGINATA POLYMASTIA_INFLATA
         POLYMASTIA_HIRSUTA POLYMASTIA_CORTICATA POLYMASTIA_CONIGERA
         POLYMASTIA_AGGLUTINARIS

      -- Class 7:
        - Objects (7 sponges):

         SPHAEROTYLUS_ANTARCTICUS POLYMASTIA_TISSIERI POLYMASTIA_MARTAE
         POLYMASTIA_INFRAPILOSA POLYMASTIA_GRIMALDI POLYMASTIA_FUSCA
         POLYMASTIA_ECTOFIBROSA

      -- Class 8:
        - Objects (6 sponges):

         WEBERELLA_VERRUCOSA WEBERELLA_BURSA RIDLEYA_OVIFORMIS
         QUASILINA_RICHARDII QUASILINA_INTERMEDIA QUASILINA_BREVIS

      -- Class 9:
        - Objects (2 sponges):

         SUBERITES_FICUS SUBERITES_DOMUNCULA

      -- Class 10:
        - Objects (2 sponges):

          TETHYA_CITRINA TETHYA_AURANTIUM

      -- Class 11:
        - Objects (5 sponges):

          TIMEA_UNISTELLATA TIMEA_STELLATA TIMEA_MIXTA
          TIMEA_HALLEZI TIMEA_CHONDRILLOIDES

      -- Class 12:
        - Objects (2 sponges):

          TRICHOSTEMA_SARSI TRICHOSTEMA_HEMISPHAERICUM